# ISO 6346 Freight Containers: Coding, Identification and Marking

## Synopsis

CSC owner codes.

The calculation is based upon:

 * [How is the check digit of a container calculated? — Grand View Container Trading](http://www.gvct.co.uk/2011/09/how-is-the-check-digit-of-a-container-calculated/)
 * [ISO 6346:2022 Freight containers — Coding, identification and marking](https://www.iso.org/standard/83558.html)
